Documentation
¶
Index ¶
- type Twitter
- func (t *Twitter) CacheRandomTweets(ctx context.Context) error
- func (t *Twitter) CacophonyCron(ctx context.Context) error
- func (t *Twitter) GetTweet(ctx context.Context, id int64) (*twitter.Tweet, error)
- func (t *Twitter) SaveUserTweets(ctx context.Context) error
- func (t *Twitter) UploadTweet(ctx context.Context, tw twitter.Tweet) error
- type TwitterAuth
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Twitter ¶
type Twitter struct {
shared.Config
TwitterAuth *TwitterAuth
GraphQLToken string
}
Twitter contains the context needed for working with twitter.
func (*Twitter) CacheRandomTweets ¶
CacheRandomTweets gets random tweets from graphql, and if we are missing their data, gets it from twitter and uploads to graphql.
func (*Twitter) CacophonyCron ¶
CacophonyCron triggers the cacophony cron.
func (*Twitter) SaveUserTweets ¶
SaveUserTweets gets a users timeline and uploads it to graphql.
Click to show internal directories.
Click to hide internal directories.